==> gene2pathway_2.2.0.tar.gz: gene2pathway/R/buildTrainingSet.signaltrans.R <==
buildTrainingSet.signaltrans = function(minnmap=10, organism="hsa", remove.duplicates=FALSE, gene2Domains=NULL){
	organisms=list.organisms()
	if(!(organism %in% names(organisms)))
		stop(paste("Organism '", organism, "' unknown in KEGG! Please refer to <URL:http://www.genome.jp/kegg-bin/create_kegg_menu> for a complete list of supported organisms."))
	cat("Retrieving KEGG information via SOAP ...\n", sep="")
	kegg_hierarchy = gene2pathway:::getKEGGHierarchy()
	signaltrans = kegg_hierarchy$pathNamesLev2[grep("Signal Transduction", kegg_hierarchy$pathNamesLev2)]
	sig.pathways = names(which(sapply(kegg_hierarchy$parentPaths, function(p) signaltrans %in% unlist(p))))
	pathways = list.pathways(organism)
	pathways = gsub(" - .*", "", pathways)
	sig.pathways = pathways[pathways %in% sig.pathways]
	pathwayIDs = names(sig.pathways)
	genes = try(lapply(pathwayIDs, get.genes.by.pathway))
	names(genes) = sig.pathways
	genes = lapply(genes, function(g) sub(paste(organism,"\\:",sep=""),"", g))
	sig.pathways = sig.pathways[sapply(genes, length) > 0]

	if(organism != "hsa")
		KEGG2Entrez.table = gene2pathway:::KEGG2Entrez(organism=organism)
	else
		KEGG2Entrez.table = NULL
	clustall = try(sapply(names(sig.pathways), getComponents.internal, KEGG2Entrez.table))
	clust = clustall["geneIDs",]
	elems = clustall["elemIDs",]
	names(clust) = sig.pathways[names(clust)] #sub(paste("path:",organism,sep=""),"",names(clust))
	names(elems) = sig.pathways[names(elems)] #sub(paste("path:",organism,sep=""),"",names(elems))
	clust = clust[!sapply(clust, function(c) is.null(c))]		
	allen = sapply(sapply(clust, function(c) if(class(c) == "list") sapply(c,length) else length(c)), length)	
	roots = names(clust)
	childs = roots[allen > 1]
	childs = unlist(sapply(childs, function(c) paste(c, seq(1:allen[c]),sep=".")))
	levels = c(roots, childs)	
	hKEGGgenes = unique(unlist(clust))		
	if(length(hKEGGgenes) == 0)
		stop("No connected components could be found!")
	cat("done\n")
	
	if(!is.null(gene2Domains) && length(intersect(hKEGGgenes, names(gene2Domains))) == 0)
		stop("There is a conflict between KEGG Entrez gene / open reading frame IDs and the gene identifiers in list 'gene2Domains'.\n 'gene2Domains' should be a list of Entrez gene IDs and their correponding InterPro domains.")
	features = gene2pathway:::getInterProDomains(hKEGGgenes, gene2Domains=gene2Domains, organism=organism)
	if(remove.duplicates)
		features = unique(features)
	common = intersect(hKEGGgenes, rownames(features))
	features = features[common,]
	features = features[,colSums(features) > 0]
	
	parentPaths = vector("list", length=length(childs))
	names(parentPaths) = childs
	labels = matrix(0, ncol=length(levels), nrow=nrow(features))
	colnames(labels) = levels 
	rownames(labels) = rownames(features)
	for(l in 1:length(clust)){		
		myparent = names(clust)[l]
		if(class(clust[[l]]) == "list"){
			for(ll in 1:length(clust[[l]])){ # put labels for each sub-class
				genesInClust = intersect(clust[[l]][[ll]], rownames(labels))		
				mypath = paste(myparent,ll,sep=".")
				labels[genesInClust, mypath] = 1		
				parentPaths[mypath] = myparent
			}
		}	
		genesInClust = intersect(unlist(clust[[l]]), rownames(labels))
		labels[genesInClust, myparent] = 1			
	}		
	labels = labels[,colSums(labels) > minnmap]	
	freq = table(unlist(parentPaths[colnames(labels)]))
	redchild = paste(names(freq[freq == 1]),"[1-9]",sep=".")
	labels = labels[,setdiff(1:ncol(labels), unlist(sapply(redchild, grep, colnames(labels))))]
	cat("Removing hierarchy branches with < ", minnmap, " mapping genes\n--->", ncol(labels), "hierarchy branches left\n")
	if(ncol(labels) == 0)
		stop("No sufficient number of mapping genes! Impossible to train model.")
		
	treesizes = double(ncol(labels))+1
	names(treesizes) = colnames(labels)
	freq = table(unlist(parentPaths[colnames(labels)]))
	treesizes[names(freq)] = freq
	treesizes = treesizes / sum(treesizes)
	
	kegg_hierarchy$parentsLev1 = which(colnames(labels) %in% names(clust))
	kegg_hierarchy$parentsLev2 = setdiff(1:ncol(labels), kegg_hierarchy$parentsLev1)
	kegg_hierarchy$parentsLev12 = c()
	elems = elems[colnames(labels)[kegg_hierarchy$parentsLev1]]
	
	list(features=features, labels=labels, treesizes=treesizes, elemIDs=elems, kegg_hierarchy=kegg_hierarchy)
}

==> gene2pathway_2.6.0.tar.gz: gene2pathway/R/buildTrainingSet.signaltrans.R <==
buildTrainingSet.signaltrans = function(minnmap=10, organism="hsa", remove.duplicates=FALSE, gene2Domains=NULL){
	organisms=list.organisms()
	organisms = sapply(organisms, function(x) x@entry_id)
	if(!(organism %in% organisms))
		stop(paste("Organism '", organism, "' unknown in KEGG! Please refer to <URL:http://www.genome.jp/kegg-bin/create_kegg_menu> for a complete list of supported organisms."))
	cat("Retrieving KEGG information via SOAP ...\n", sep="")
	kegg_hierarchy = gene2pathway:::getKEGGHierarchy()
	signaltrans = kegg_hierarchy$pathNamesLev2[grep("Signal Transduction", kegg_hierarchy$pathNamesLev2)]
	sig.pathways = names(which(sapply(kegg_hierarchy$parentPaths, function(p) signaltrans %in% unlist(p))))
	pathways = list.pathways(organism)
	pathways.names = sapply(pathways, function(x) x@entry_id)
	pathways = sapply(pathways, function(x) x@definition)
	pathways = gsub(" - .*", "", pathways)		
	names(pathways) = pathways.names
	sig.pathways = pathways[pathways %in% sig.pathways]
	pathwayIDs = names(sig.pathways)
	genes = try(lapply(pathwayIDs, get.genes.by.pathway))
	names(genes) = sig.pathways
	genes = lapply(genes, function(g) sub(paste(organism,"\\:",sep=""),"", g))
	sig.pathways = sig.pathways[sapply(genes, length) > 0]

#	if(organism != "hsa")
#		KEGG2Entrez.table = gene2pathway:::KEGG2Entrez(organism=organism)
#	else
#		KEGG2Entrez.table = NULL
	clustall = try(sapply(names(sig.pathways), getComponents, organism=organism))
	clust = clustall["geneIDs",]
	elems = clustall["elemIDs",]
	names(clust) = sig.pathways[names(clust)] #sub(paste("path:",organism,sep=""),"",names(clust))
	names(elems) = sig.pathways[names(elems)] #sub(paste("path:",organism,sep=""),"",names(elems))
	clust = clust[!sapply(clust, function(c) is.null(c))]		
	allen = sapply(sapply(clust, function(c) if(class(c) == "list") sapply(c,length) else length(c)), length)	
	roots = names(clust)
	childs = roots[allen > 1]
	childs = unlist(sapply(childs, function(c) paste(c, seq(1:allen[c]),sep=".")))
	levels = c(roots, childs)	
	hKEGGgenes = unique(unlist(clust))		
	if(length(hKEGGgenes) == 0)
		stop("No connected components could be found!")
	cat("done\n")
	
	if(!is.null(gene2Domains) && length(intersect(hKEGGgenes, names(gene2Domains))) == 0)
		stop("There is a conflict between KEGG Entrez gene / open reading frame IDs and the gene identifiers in list 'gene2Domains'.\n 'gene2Domains' should be a list of Entrez gene IDs and their correponding InterPro domains.")
	features = gene2pathway:::getInterProDomains(hKEGGgenes, gene2Domains=gene2Domains, organism=organism)
	if(remove.duplicates)
		features = unique(features)
	common = intersect(hKEGGgenes, rownames(features))
	features = features[common,]
	features = features[,colSums(features) > 0]
	
	parentPaths = vector("list", length=length(childs))
	names(parentPaths) = childs
	labels = matrix(0, ncol=length(levels), nrow=nrow(features))
	colnames(labels) = levels 
	rownames(labels) = rownames(features)
	for(l in 1:length(clust)){		
		myparent = names(clust)[l]
		if(class(clust[[l]]) == "list"){
			for(ll in 1:length(clust[[l]])){ # put labels for each sub-class
				genesInClust = intersect(clust[[l]][[ll]], rownames(labels))		
				mypath = paste(myparent,ll,sep=".")
				labels[genesInClust, mypath] = 1		
				parentPaths[mypath] = myparent
			}
		}	
		genesInClust = intersect(unlist(clust[[l]]), rownames(labels))
		labels[genesInClust, myparent] = 1			
	}		
	labels = labels[,colSums(labels) > minnmap]	
	freq = table(unlist(parentPaths[colnames(labels)]))
	redchild = paste(names(freq[freq == 1]),"[1-9]",sep=".")
	labels = labels[,setdiff(1:ncol(labels), unlist(sapply(redchild, grep, colnames(labels))))]
	cat("Removing hierarchy branches with < ", minnmap, " mapping genes\n--->", ncol(labels), "hierarchy branches left\n")
	if(ncol(labels) == 0)
		stop("No sufficient number of mapping genes! Impossible to train model.")
		
	treesizes = double(ncol(labels))+1
	names(treesizes) = colnames(labels)
	freq = table(unlist(parentPaths[colnames(labels)]))
	treesizes[names(freq)] = freq
	treesizes = treesizes / sum(treesizes)
	
	kegg_hierarchy$parentsLev1 = which(colnames(labels) %in% names(clust))
	kegg_hierarchy$parentsLev2 = setdiff(1:ncol(labels), kegg_hierarchy$parentsLev1)
	kegg_hierarchy$parentsLev12 = c()
	elems = elems[colnames(labels)[kegg_hierarchy$parentsLev1]]
	
	list(features=features, labels=labels, treesizes=treesizes, elemIDs=elems, kegg_hierarchy=kegg_hierarchy)
}
